@@ -14,8 +14,8 @@
 #'   recipe will need to be refit.
 #'
 #' @details
-#' To fit a workflow, one of `add_formula()` or `add_recipe()` _must_ be
-#' specified, but not both.
+#' To fit a workflow, exactly one of [add_formula()], [add_recipe()], or
+#' [add_variables()] _must_ be specified.
 #'
 #' @param x A workflow
 #'
@@ -101,6 +101,9 @@ check_conflicts.action_recipe <- function(action, x) {
   if (has_action(pre, "formula")) {
     abort("A recipe cannot be added when a formula already exists.")
   }
+  if (has_action(pre, "variables")) {
+    abort("A recipe cannot be added when variables already exist.")
+  }
 
   invisible(action)
 }
